@@ -18,9 +18,9 @@ from QiDataProcessing.TradingFrame.YfTimeHelper import YfTimeHelper
 pd.set_option('display.max_columns', None)
 pd.set_option('display.width', 1000)
 
-trading_day = datetime.datetime(2019, 10, 13)
+trading_day = datetime.datetime(2020, 10, 13)
 tick_path = "\\\\192.168.1.200\\MqData\\futuretick\\Future"
-min_path = "\\\\192.168.1.200\\MqData\\futuremin"
+min_path = "D:\\MqData\\futuremin"
 day_path = "\\\\192.168.1.200\\MqData\\futureday"
 
 qi_data_directory = QiDataDirectory()
@@ -30,31 +30,34 @@ qi_data_directory.future_tick_cache = tick_path
 qi_data_directory.future_min = min_path
 qi_data_directory.future_day = day_path
 
-instrument_id = 'IC9999'
-begin_trading_date = datetime.datetime(2020, 1, 1)
-end_trading_date = datetime.datetime(2021, 3, 1)
-interval = 5
+instrument_id = 'SR105'
+begin_trading_date = datetime.datetime(2020, 5, 1)
+end_trading_date = datetime.datetime(2020, 5, 10)
+interval = 1
 bar_type = EnumBarType.minute
-begin_date = datetime.datetime(2020, 1, 10)
-end_date =  datetime.datetime(2021, 1, 30)
-t0 = time.time()
 qi_data_controller = QiDataController(qi_data_directory)
-bar_series_min = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, 1, bar_type, begin_trading_date, end_trading_date)
-config_dir = os.path.join(sys.modules['ROOT_DIR'], 'Config')
-instrument_manager = InstrumentManager()
-instrument_manager.load(config_dir, EnumMarket.期货)
-bar_provider = BarProvider()
-bar_provider.create_bar_provider_by_date(instrument_manager, instrument_id, begin_date, end_date, interval, bar_type)
-for bar in bar_series_min:
-    bar_provider.add_bar(bar)
-
-bar_series = bar_provider.bar_series
+bar_series = qi_data_controller.load_bar_series_by_date(EnumMarket.期货, instrument_id, 1, bar_type, begin_trading_date, end_trading_date)
 for bar in bar_series:
     print(bar.to_string())
-bar_s = filter(lambda x:x.trading_date==datetime.datetime(2020,12,30), bar_series)
-for bar in bar_s:
-    print(bar.to_string())
-print(time.time()-t0)
+
+# begin_date = datetime.datetime(2020, 1, 10)
+# end_date = datetime.datetime(2021, 1, 30)
+# t0 = time.time()
+# config_dir = os.path.join(sys.modules['ROOT_DIR'], 'Config')
+# instrument_manager = InstrumentManager()
+# instrument_manager.load(config_dir, EnumMarket.期货)
+# bar_provider = BarProvider()
+# bar_provider.create_bar_provider_by_date(instrument_manager, instrument_id, begin_date, end_date, interval, bar_type)
+# for bar in bar_series_min:
+#     bar_provider.add_bar(bar)
+#
+# bar_series = bar_provider.bar_series
+# for bar in bar_series:
+#     print(bar.to_string())
+# bar_s = filter(lambda x:x.trading_date==datetime.datetime(2020,12,30), bar_series)
+# for bar in bar_s:
+#     print(bar.to_string())
+# print(time.time()-t0)
 # instrument = qi_data_controller.instrument_manager['IC9999']
 # print(instrument)
 # interval = 3
